@@ -2,8 +2,7 @@
 #'
 #' @export
 #'
-#' @param query Name to search for. If left blank, the first ten results are returned
-#' using a more or less random search.
+#' @param query Name to search for. Required.
 #' @param method The field to query by. See description below for details.
 #' @param exact Exact matching or not. See examples. Defaults to FALSE.
 #' @param parsed If TRUE (default) creates data.frame of names data output. Otherwise,
@@ -27,6 +26,9 @@
 #' }
 #' @seealso \code{\link{bison_solr}} \code{\link{bison}}
 #' @examples \dontrun{
+#' # All taxa
+#' bison_tax("*:*")
+#' 
 #' # Some example calls
 #' bison_tax(query="*bear")
 #' bison_tax(query="Helianthus", method="scientificName")
@@ -47,16 +49,21 @@
 #' bison_tax(query='*dolphin', callopts=verbose())
 #' }
 
-bison_tax <- function(query=NULL, method='vernacularName', exact=FALSE, parsed=TRUE,
+bison_tax <- function(query, method='vernacularName', exact=FALSE, parsed=TRUE,
   callopts=list(), ...)
 {
-  method <- match.arg(method, choices=c('vernacularName','scientificName'))
-  if(!length(method)==1)
+  method <- match.arg(method, choices = c('vernacularName','scientificName'))
+  if (!length(method) == 1) {
   	stop("method can only be of length 1")
-  url <- sprintf('http://bisonapi.usgs.ornl.gov/solr/%s/select', method)
-  if(exact){ qu_ <- paste0('"', query, '"') } else { qu_ <- query }
-  args <- bs_compact(list(q=qu_, wt="json", ...))
-  tt <- GET(url, query=args, callopts)
+  }
+  url <- sprintf('http://bison.usgs.ornl.gov/solrstaging/%s/select', method)
+  if (exact) { 
+    qu_ <- paste0('"', query, '"') 
+  } else { 
+    qu_ <- query 
+  }
+  args <- bs_compact(list(q = qu_, wt = "json", ...))
+  tt <- GET(url, query = args, c(config(followlocation = 1), callopts))
   stop_for_status(tt)
   out <- content(tt)
   temp <- list(
@@ -66,8 +73,8 @@ bison_tax <- function(query=NULL, method='vernacularName', exact=FALSE, parsed=T
     facets = out$facet_counts
   )
 
-  if(parsed){
-    data <- rbind_all(lapply(out$response$docs, data.frame, stringsAsFactors=FALSE))
+  if (parsed) {
+    data <- rbind_all(lapply(out$response$docs, data.frame, stringsAsFactors = FALSE))
     data$X_version_ <- NULL
     temp$names <- data
   }
